@@ -30,20 +30,15 @@ class _Feature(Enum):
 
 
 class Column:
-    def __init__(self, series, counts, p_t, p_z):
+    def __init__(self, series, p_t, p_z):
         self.series = series
         self.p_t = p_t
-        self.p_t_canonical = {}
         self.p_z = p_z
         self.type = self.inferred_type()
-        self.unique_vals, self.unique_vals_counts = _get_unique_vals(self.series, return_counts=True)
-        self._initialise_missing_anomalies()
-        features = self._get_features(counts)
-        self.arff_type = _column2ARFF.get_arff(features)[0]
-        self.arff_posterior = _column2ARFF.get_arff(features)[1]
-        self.categorical_values = (
-            self.get_normal_values() if self.arff_type == "nominal" else None
+        self.unique_vals, self.unique_vals_counts = _get_unique_vals(
+            self.series, return_counts=True
         )
+        self._initialise_missing_anomalies()
 
     def __repr__(self):
         return repr(self.__dict__)
@@ -53,8 +48,12 @@ class Column:
         max_row_posterior_indices = np.argmax(row_posteriors, axis=1)
 
         self.normal_indices = list(np.where(max_row_posterior_indices == TYPE_INDEX)[0])
-        self.missing_indices = list(np.where(max_row_posterior_indices == MISSING_INDEX)[0])
-        self.anomalous_indices = list(np.where(max_row_posterior_indices == ANOMALIES_INDEX)[0])
+        self.missing_indices = list(
+            np.where(max_row_posterior_indices == MISSING_INDEX)[0]
+        )
+        self.anomalous_indices = list(
+            np.where(max_row_posterior_indices == ANOMALIES_INDEX)[0]
+        )
 
     def inferred_type(self):
         """Get most likely inferred type for the column."""
@@ -62,15 +61,27 @@ class Column:
 
     def get_normal_ratio(self):
         """Get proportion of unique values in the column which are considered neither anomalous nor missing."""
-        return round(sum(self.unique_vals_counts[self.normal_indices]) / sum(self.unique_vals_counts), 2)
+        return round(
+            sum(self.unique_vals_counts[self.normal_indices])
+            / sum(self.unique_vals_counts),
+            2,
+        )
 
     def get_na_ratio(self):
         """Get proportion of unique values in the column which are considered 'missing'."""
-        return round(sum(self.unique_vals_counts[self.missing_indices]) / sum(self.unique_vals_counts), 2)
+        return round(
+            sum(self.unique_vals_counts[self.missing_indices])
+            / sum(self.unique_vals_counts),
+            2,
+        )
 
     def get_an_ratio(self):
         """Get proportion of unique values in the column which are considered 'anomalous'."""
-        return round(sum(self.unique_vals_counts[self.anomalous_indices]) / sum(self.unique_vals_counts), 2)
+        return round(
+            sum(self.unique_vals_counts[self.anomalous_indices])
+            / sum(self.unique_vals_counts),
+            2,
+        )
 
     def get_normal_values(self):
         """Get list of all values in the column which are considered neither anomalous nor missing."""
@@ -94,10 +105,10 @@ class Column:
             raise Exception(f"Type {new_t} is unknown.")
         self.type = new_t
         self._initialise_missing_anomalies()
-        # update the arff types?
 
     def _get_features(self, counts):
         posterior = OrderedDict()
+        # handle equal probs
         for t, p in sorted(self.p_t.items()):
             # aggregate date subtypes
             t_0 = t.split("-")[0]
@@ -122,25 +133,8 @@ class Column:
 
         return np.array(list(posterior) + [u_ratio, u_ratio_clean, U, U_clean])
 
+    def set_p_t_cat(self, t_hat, p_cat):
+        self.p_t["categorical"] = self.p_t[t_hat] * p_cat
+        self.p_t[t_hat] = 1 - self.p_t["categorical"]
+        self.type = self.inferred_type()
 
-class _Column2ARFF:
-    def __init__(self, model_folder="models"):
-        self.normalizer = joblib.load(model_folder + "robust_scaler.pkl")
-        self.clf = joblib.load(model_folder + "LR.sav")
-
-    def get_arff(self, features):
-        features[[_Feature.U.value, _Feature.U_CLEAN.value]] = self.normalizer.transform(
-            features[[_Feature.U.value, _Feature.U_CLEAN.value]].reshape(1, -1)
-        )[0]
-        arff_type = self.clf.predict(features.reshape(1, -1))[0]
-
-        if arff_type == "categorical":
-            arff_type = "nominal"
-        # find normal values for categorical type
-
-        arff_type_posterior = self.clf.predict_proba(features.reshape(1, -1))[0]
-
-        return arff_type, arff_type_posterior
-
-
-_column2ARFF = _Column2ARFF(project_root() + "/../models/")
