@@ -15,7 +15,8 @@ from ptype.utils import normalize_log_probs, LOG_EPS
 
 
 class Ptype:
-    """The ptype object."""
+    """The Ptype object. It uses the following data types: date, integer, float and string."""
+
     def __init__(self):
         self.types = [
             "integer",
@@ -56,6 +57,7 @@ class Ptype:
         return Schema(df, cols)
 
     def _column(self, df, col_name, logP, counts):
+        """Returns a Column object for a given data column."""
         # Constants
         I, J = logP.shape  # num of rows x num of data types
         K = J - 2  # num of possible column data types (excluding missing and catch-all)
@@ -78,13 +80,9 @@ class Ptype:
             p_z[self.types[k]] = p_z_k / p_z_k.sum(axis=1)[:, np.newaxis]
 
         p_t = normalize_log_probs(p_t)
+        p_t = {t: p for t, p in zip(self.types, p_t)}
 
-        return Column(
-            series=df[col_name],
-            counts=counts,
-            p_t={t: p for t, p in zip(self.types, p_t)},
-            p_z=p_z,
-        )
+        return Column(series=df[col_name], p_t=p_t, p_z=p_z)
 
     def get_na_values(self):
         """Get list of all values which Ptype considers to mean 'missing' or 'na'."""
